How to Contribute to the Google Auth Library for Perl

Overview: We Welcome Your Contributions

Welcome and thank you for your interest in contributing to the Google Auth Library for Perl. Open source contributions are important to foster a vibrant developer community and help us provide a world-class developer experience. We value your contributions, no matter how small. Even small documentation fixes can go a long way in helping other developers use our API. Before contributing, please review the guidelines and best practices below.

Providing Feedback

Feature Requests

We appreciate your feedback and encourage you to submit feature requests that will help improve this library. You can submit feature requests by opening an issue on GitHub: https://github.com/GoogleCloudPlatform/google-auth-library-perl/issues

Bug Reports

We appreciate your feedback and encourage you to report bugs that will help improve this library. Please report bugs by opening an issue on GitHub: https://github.com/GoogleCloudPlatform/google-auth-library-perl/issues

Please do not include any personal identifiable information or authorization/access data in any of the information you post.

Contributing

Contributor License Agreement (CLA)

Contributions to this project must be accompanied by a Contributor License Agreement. You (or your employer) retain the copyright to your contribution; this simply gives us permission to use and redistribute your contributions as part of the project. Head over to https://cla.developers.google.com/ to see your current agreements on file or to sign a new one.

Pull Request Submission Best Practices

When making a pull request, first make your own forked copy of this repository, make any changes on a separate branch of that forked copy, then submit the pull request from your new fork/branch to: https://github.com/GoogleCloudPlatform/google-auth-library-perl/pulls

Style Guidelines & Naming Conventions

Please conform your submitted code to the official Perl style guide. You can use perltidy to reformat your code based on the .perltidyrc file to comply with Google Style. In addition, please leave comments in your code in a manner consistent with other code in this repository.

Testing

If you make any changes to this codebase, ensure that all existing tests continue to pass. In addition, add tests that validate your changes to ensure that future changes do not break your new feature or bug fix.

Community Guidelines

This project follows Google's Open Source Community Guidelines.